
function []=riktningsfaelt(f,t,u)
% riktningsfaelt - ritar riktningsfält till differentialekvationen u'=f(t,u)
%   Syntax:
%           [] = riktningsfaelt(f,t,u)
%   Argument:
%           f - funktionshandtag: pekar på namnet till en funktionsfil eller
%               till en anonym funktion, t.ex. f=@funk
%           t - en vektor med stigande t-värden i intervallet.
%           u - en vektor med stigande u-värden.
%   Returnerar:
%           -
%   Beskrivning:
%           Programmet ritar riktningsfältet till differentialekvationen u'=f(t,u) över 
%           det område som ges av vektorerna t och u.  
%   Exempel:
%           f=@(t,u)-u+sin(t)+cos(t);
%           a=0; b=4;
%           t=linspace(a,b,15); u=linspace(-2,2,15); 
%           riktningsfaelt(f,t,u)
    dt=0.5*(t(2)-t(1));
    axis([t(1) t(end) u(1) u(end)])
    hold on
    for i=1:length(t)
        ti=t(i);
        for j=1:length(u)
            uj=u(j);
            fj=f(ti,uj);
            plot([ti ti+dt],[uj uj+dt*fj],'k')
        end
    end

